#ifdef __LIBBASS_BAS__
#error 666: included twice !
#else

#define __LIBBASS_BAS__

#include once "libbass.bi"

function BASS_T.GetVersionsString as string 
  if this.mError then return "Bass no version error: loading " & BASS_LIB_NAME
  dim as ulong ver = this.GetVersion()
  return "Bass version " & hibyte(hiword(ver)) & "." & lobyte(hiword(ver))
end function

function BASS_T.IsErrorOnLoad as integer
  return (mError<>0)
end function

function BASS_T.GetErrorString as String
  if this.mError then return "error: loading " & BASS_LIB_NAME
  select case as const this.ErrorGetCode()
  case BASS_OK             : return "0 all is OK"
  case BASS_ERROR_MEM      : return "1 memory error"
  case BASS_ERROR_FILEOPEN : return "2 can't open the file"
  case BASS_ERROR_DRIVER   : return "3 can't find a free/valid driver"
  case BASS_ERROR_BUFLOST  : return "4 the sample buffer was lost"
  case BASS_ERROR_HANDLE   : return "5 invalid handle"
  case BASS_ERROR_FORMAT   : return "6 unsupported sample format"
  case BASS_ERROR_POSITION : return "7 invalid position"
  case BASS_ERROR_INIT     : return "8 BASS.Init has not been successfully called"
  case BASS_ERROR_START    : return "9 BASS.Start has not been successfully called"

  case BASS_ERROR_SSL      : return "10 SSL/HTTPS support isn't available"
  case BASS_ERROR_ALREADY  : return "14 already initialized/paused/whatever"
  case BASS_ERROR_NOCHAN   : return "18 can't get a free channel"
  case BASS_ERROR_ILLTYPE  : return "19 an illegal type was specified"

  case BASS_ERROR_ILLPARAM : return "20 an illegal parameter was specified"
  case BASS_ERROR_NO3D     : return "21 no 3D support"
  case BASS_ERROR_NOEAX    : return "22 no EAX support"
  case BASS_ERROR_DEVICE   : return "23 illegal device number"
  case BASS_ERROR_NOPLAY   : return "24 not playing"
  case BASS_ERROR_FREQ     : return "25 illegal sample rate"
  case BASS_ERROR_NOTFILE  : return "27 the stream is not a file stream"
  case BASS_ERROR_NOHW     : return "29 no hardware voices available"

  case BASS_ERROR_EMPTY    : return "31 the MOD music has no sequence data"
  case BASS_ERROR_NONET    : return "32 no internet connection could be opened"
  case BASS_ERROR_CREATE   : return "33 couldn't create the file"
  case BASS_ERROR_NOFX     : return "34 effects are not available"
  case BASS_ERROR_NOTAVAIL : return "37 requested data is not available"
  case BASS_ERROR_DECODE   : return "38 the channel is/isn't a 'decoding channel'"
  case BASS_ERROR_DX       : return "39 a sufficient DirectX version is not installed"

  case BASS_ERROR_TIMEOUT  : return "40 connection timedout"
  case BASS_ERROR_FILEFORM : return "41 unsupported file format"
  case BASS_ERROR_SPEAKER  : return "42 unavailable speaker"
  case BASS_ERROR_VERSION  : return "43 invalid BASS version (used by add-ons)"
  case BASS_ERROR_CODEC    : return "44 codec is not available/supported"
  case BASS_ERROR_ENDED    : return "45 the channel/file has ended"
  case BASS_ERROR_BUSY     : return "46 the device is busy"

  case else                : return "unkow problem"
  end select
end function 


destructor BASS_T
  if mhLib then
    'this.Free()
    dylibfree mhLib : mhLib=0
  end if
end destructor

constructor BASS_T
  mError=0
  mhLib=dylibload(BASS_LIB_NAME)
  if mhLib=0 then mError=1
  if mError=0 then
  #define DEFBASS(_name_) _name_ =  DyLibSymbol(mhLib, "BASS_" & #_name_) : if _name_=0 then mError=1
  DEFBASS(SetConfig)
  DEFBASS(GetConfig)
  DEFBASS(SetConfigPtr)
  DEFBASS(GetConfigPtr)
  DEFBASS(ErrorGetCode)
  DEFBASS(GetDeviceInfo)
#ifdef __FB_WIN32__
  DEFBASS(GetDSoundObject)
  DEFBASS(SetEAXParameters)
  DEFBASS(GetEAXParameters)
#endif
  DEFBASS(Init)

  DEFBASS(GetVersion)
  DEFBASS(SetDevice)
  DEFBASS(GetDevice)
  DEFBASS(Free)
  DEFBASS(GetInfo)
  DEFBASS(Update)
  DEFBASS(GetCPU)

  DEFBASS(Start)
  DEFBASS(Stop)
  DEFBASS(Pause)

  DEFBASS(SetVolume)
  DEFBASS(GetVolume)

  DEFBASS(PluginLoad)
  DEFBASS(PluginFree)
  DEFBASS(PluginGetInfo)

  DEFBASS(Set3DFactors)
  DEFBASS(Get3DFactors)
  DEFBASS(Set3DPosition)
  DEFBASS(Get3DPosition)
  DEFBASS(Apply3D)

  DEFBASS(MusicLoad)
  DEFBASS(MusicFree)

  DEFBASS(SampleLoad)
  DEFBASS(SampleCreate)
  DEFBASS(SampleFree)
  DEFBASS(SampleSetData)
  DEFBASS(SampleGetData)
  DEFBASS(SampleGetInfo)
  DEFBASS(SampleSetInfo)
  DEFBASS(SampleGetChannel)
  DEFBASS(SampleGetChannels)
  DEFBASS(SampleStop)

  DEFBASS(StreamCreate)
  DEFBASS(StreamCreateFile)
  DEFBASS(StreamCreateURL)
  DEFBASS(StreamCreateFileUser)
  DEFBASS(StreamFree)
  DEFBASS(StreamGetFilePosition)
  DEFBASS(StreamPutData)
  DEFBASS(StreamPutFileData)

  DEFBASS(RecordGetDeviceInfo)
  DEFBASS(RecordInit)
  DEFBASS(RecordSetDevice)
  DEFBASS(RecordGetDevice)
  DEFBASS(RecordFree)
  DEFBASS(RecordGetInfo)
  DEFBASS(RecordGetInputName)
  DEFBASS(RecordSetInput)
  DEFBASS(RecordGetInput)
  DEFBASS(RecordStart)

  DEFBASS(ChannelBytes2Seconds)
  DEFBASS(ChannelSeconds2Bytes)
  DEFBASS(ChannelGetDevice)
  DEFBASS(ChannelSetDevice)
  DEFBASS(ChannelIsActive)
  DEFBASS(ChannelGetInfo)
  DEFBASS(ChannelGetTags)
  DEFBASS(ChannelFlags)
  DEFBASS(ChannelUpdate)
  DEFBASS(ChannelLock)
  DEFBASS(ChannelPlay)
  DEFBASS(ChannelStop)
  DEFBASS(ChannelPause)
  DEFBASS(ChannelSetAttribute)
  DEFBASS(ChannelGetAttribute)
  DEFBASS(ChannelSlideAttribute)
  DEFBASS(ChannelIsSliding)
  DEFBASS(ChannelSet3DAttributes)
  DEFBASS(ChannelGet3DAttributes)
  DEFBASS(ChannelSet3DPosition)
  DEFBASS(ChannelGet3DPosition)
  DEFBASS(ChannelGetLength)
  DEFBASS(ChannelSetPosition)
  DEFBASS(ChannelGetPosition)
  DEFBASS(ChannelGetLevel)
  DEFBASS(ChannelGetData)
  DEFBASS(ChannelSetSync)
  DEFBASS(ChannelRemoveSync)
  DEFBASS(ChannelSetDSP)
  DEFBASS(ChannelRemoveDSP)
  DEFBASS(ChannelSetLink)
  DEFBASS(ChannelRemoveLink)
  DEFBASS(ChannelSetFX)
  DEFBASS(ChannelRemoveFX)

  DEFBASS(FXSetParameters)
  DEFBASS(FXGetParameters)
  DEFBASS(FXReset)
  end if
  #undef DEFBASS
end constructor

dim shared as BASS_T BASS 

#endif ' __LIBBASS_BAS__